<?php

namespace SGalinski\SgNews\ViewHelpers;

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractViewHelper;

class RelatedViewHelper extends AbstractViewHelper {
	/**
	 * Initialize the view helper arguments
	 */
	public function initializeArguments() {
		$this->registerArgument(
			'news',
			'SGalinski\SgNews\Domain\Model\News',
			'The news record from which to find related news',
			TRUE
		);
		$this->registerArgument('limit', 'int', 'Limit the amount of related news to display', FALSE, 5);
		$this->registerArgument('as', 'string', 'The name of the iteration variable', TRUE);
		$this->registerArgument('iteration', 'string', 'The name of the variable to store iteration information (index, cycle, isFirst, isLast, isEven, isOdd)');
	}

	/**
	 * Render the ViewHelper
	 * It works like the for-ViewHelper by running through the child content and adding the related news records to it
	 *
	 * @return string
	 */
	public function render() {
		$news = $this->arguments['news'];
		$newsRepository = GeneralUtility::makeInstance(NewsRepository::class);
		$related = $newsRepository->findRelated($news);
		$templateVariableContainer = $this->renderingContext->getVariableProvider();
		$output = '';
		if (isset($this->arguments['iteration'])) {
            $iterationData = [
                'index' => 0,
                'cycle' => 1,
                'total' => count($related)
            ];
        }
		foreach ($related as $relatedNews) {
			$templateVariableContainer->add($this->arguments['as'], $relatedNews);
			if (isset($this->arguments['iteration'])) {
                $iterationData['isFirst'] = $iterationData['cycle'] === 1;
                $iterationData['isLast'] = $iterationData['cycle'] === $iterationData['total'];
                $iterationData['isEven'] = $iterationData['cycle'] % 2 === 0;
                $iterationData['isOdd'] = !$iterationData['isEven'];
                $templateVariableContainer->add($this->arguments['iteration'], $iterationData);
                $iterationData['index']++;
                $iterationData['cycle']++;
            }

            $output .= $this->renderChildren();
            $templateVariableContainer->remove($this->arguments['as']);
			if (isset($this->arguments['iteration'])) {
                $templateVariableContainer->remove($this->arguments['iteration']);
            }
		}

		return $output;
	}
}
